@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 
 from django.db import models, migrations
 from django.conf import settings
@@ -31,7 +30,7 @@ class Migration(migrations.Migration):
                 ('name', models.CharField(max_length=30)),
                 ('account_sid', models.CharField(max_length=34)),
                 ('auth_token', models.CharField(max_length=32)),
-                ('user', models.OneToOneField(to=settings.AUTH_USER_MODEL)),
+                ('user', models.OneToOneField(to=settings.AUTH_USER_MODEL, on_delete=models.CASCADE)),
             ],
             options={
             },
